from setup import collection
from datetime import datetime

# Function to calculate age from DOB
def calculate_age(dob):
    if isinstance(dob, str): 
        dob = datetime.strptime(dob, "%Y-%m-%d") 

    birth_year = dob.year  # Extract year directly
    current_year = datetime.now().year
    return current_year - birth_year

# Display Person's Name and Age
print("\n--- Persons and Their Age ---")
for person in collection.find({}, {"name": 1, "dob": 1}):
    age = calculate_age(person["dob"])
    print(f"Name: {person['name']}, Age: {age}")

# Group Persons by Their Favourite Drink and Return Average Age
print("\n--- Average Age by Favourite Drink ---")
pipeline = [
    {
        "$group": {
            "_id": "$favourites.drink",
            "average_age": {"$avg": {"$subtract": [datetime.now().year, {"$toInt": {"$substr": ["$dob", 0, 4]}}]}}
        }
    }
]
results = collection.aggregate(pipeline)
for res in results:
    print(f"Drink: {res['_id']}, Average Age: {res['average_age']}")

# Display Average Age of People Who Like Hiking
print("\n--- Average Age of People Who Like Hiking ---")
pipeline = [
    {"$match": {"favourites.activity": "Hiking"}},
    {
        "$group": {
            "_id": None,
            "average_age": {"$avg": {"$subtract": [datetime.now().year, {"$toInt": {"$substr": ["$dob", 0, 4]}}]}}
        }
    }
]
result = list(collection.aggregate(pipeline))
print(f"Average age of people who like Hiking: {result[0]['average_age']}")

# Display Total Number of People from Each City
print("\n--- Total Number of People per City ---")
pipeline = [
    {"$group": {"_id": "$address.city", "total_people": {"$sum": 1}}},
    {"$sort": {"total_people": 1}}
]
results = collection.aggregate(pipeline)
for res in results:
    print(f"City: {res['_id']}, Total People: {res['total_people']}")

# Display Name of Person(s) Whose Neighbour is 'Neighbour C'
print("\n--- People Whose Neighbour is 'Neighbour C' ---")
results = collection.find({"neighbours.name": "Neighbor C"}, {"name": 1, "_id": 0})
for person in results:
    print(person["name"])
